# DiscoSnake

DiscoSnake is a the same old game which you have played in your old mobile phones.
You can feel nostalgic by playing.


Instructions:
* Use W,A,S,D keys to move.
* Feed the snake so that it grows. 
* Avoid hitting wall in all Circumstances

If you find any bugs. Please report it.

Feel free to contribute to the project.
